@@ -6,10 +6,12 @@ from pyvalid.__exceptions import InvalidArgumentNumberError, \
 
 accepts = Accepts
 returns = Returns
-version = '0.6'
+version = '0.9'
 
 
 __all__ = [
+    'validators',
+    'switch',
     'version',
     'accepts',
     'returns',
